@@ -33,14 +33,14 @@
 #'  detections, user intervention is suggested. If left NULL (default), user
 #' intervention is never suggested.
 #' @param inactive.warning If a tag spends a number of days equal or greater
-#'  than \code{inactive.error} in a given array at the tail of the respective
+#'  than \code{inactive.warning} in a given array at the tail of the respective
 #'  detections, a warning is issued. If left NULL (default), no warnings are
 #'  issued.
 #' @param jump.error If a tag crosses a number of arrays equal or greater than
 #'  \code{jump.error} without being detected, user intervention is suggested.
 #'  If left NULL (default), user intervention is never suggested.
 #' @param jump.warning If a tag crosses a number of arrays equal or greater
-#'  than \code{jump.error} without being detected, a warning is issued. If left
+#'  than \code{jump.warning} without being detected, a warning is issued. If left
 #'  NULL (default), no warnings are issued.
 #' @param max.interval The number of minutes that must pass between detections
 #'  for a new event to be created. Defaults to 60.
@@ -50,9 +50,10 @@
 #'  Defaults to 2.
 #' @param override A vector of signals for which the user intends to manually
 #'  define which movement events are valid and invalid.
-#' @param plot.detections.by The type of y axis desired for the individual
+#' @param detections.y.axis The type of y axis desired for the individual
 #'  detection plots. While the argument defaults to "auto", it can be hard-set 
 #'  to one of "stations" or "arrays".
+#' @param plot.detections.by DEPRECATED. Please use the argument detections.y.axis instead.
 #' @param print.releases Logical: Should the release sites be printed in the
 #'  study area diagrams?
 #' @param report Logical. Should an HTML report be created at the end of the
@@ -152,9 +153,14 @@ explore <- function(
   GUI = c("needed", "always", "never"),
   save.tables.locally = FALSE,
   print.releases = TRUE,
-  plot.detections.by = c("auto", "stations", "arrays")) 
+  plot.detections.by,
+  detections.y.axis = c("auto", "stations", "arrays")) 
 {
 
+# check deprecated argument
+  if (!missing(plot.detections.by))
+    stop("'plot.detections.by' has been deprecated. Please use 'detections.y.axis' instead.", call. = FALSE)
+
 # clean up any lost helpers
   deleteHelpers()
   if (file.exists(paste0(tempdir(), "/actel_debug_file.txt")))
@@ -194,14 +200,14 @@ explore <- function(
                         exclude.tags = exclude.tags,
                         override = override,
                         print.releases = print.releases,
-                        plot.detections.by = plot.detections.by)
+                        detections.y.axis = detections.y.axis)
   
   speed.method <- aux$speed.method
   speed.warning <- aux$speed.warning
   speed.error <- aux$speed.error
   inactive.warning <- aux$inactive.warning
   inactive.error <- aux$inactive.error
-  plot.detections.by <- aux$plot.detections.by
+  detections.y.axis <- aux$detections.y.axis
   rm(aux)
 
   GUI <- checkGUI(GUI, save.tables.locally = save.tables.locally)
@@ -231,7 +237,7 @@ explore <- function(
     ", GUI = '", GUI, "'",
     ", save.tables.locally = '", ifelse(save.tables.locally, "TRUE", "FALSE"),
     ", print.releases = ", ifelse(print.releases, "TRUE", "FALSE"),
-    ", plot.detections.by = '", plot.detections.by, "'",
+    ", detections.y.axis = '", detections.y.axis, "'",
     ")")
 
   appendTo("debug", the.function.call)
@@ -334,35 +340,37 @@ explore <- function(
 
   movements <- lapply(seq_along(movements), function(i) {
     tag <- names(movements)[i]
+    counter <- paste0("(", i, "/", length(movements), ")")
+
     appendTo("debug", paste0("debug: Checking movement quality for tag ", tag,"."))
 
     if (is.na(match(extractSignals(tag), override))) {
-      output <- checkMinimumN(movements = movements[[tag]], tag = tag, minimum.detections = minimum.detections)
+      output <- checkMinimumN(movements = movements[[tag]], tag = tag, minimum.detections = minimum.detections, n = counter)
 
-      output <- checkImpassables(movements = output, tag = tag, bio = bio, detections = detections.list[[tag]], 
+      output <- checkImpassables(movements = output, tag = tag, bio = bio, detections = detections.list[[tag]], n = counter, 
                                  spatial = spatial, dotmat = dotmat, GUI = GUI, save.tables.locally = save.tables.locally)
 
       output <- checkJumpDistance(movements = output, bio = bio, tag = tag, dotmat = dotmat, paths = paths, arrays = arrays,
-                                  spatial = spatial, jump.warning = jump.warning, jump.error = jump.error, GUI = GUI,
+                                  spatial = spatial, jump.warning = jump.warning, jump.error = jump.error, GUI = GUI, n = counter,
                                   detections = detections.list[[tag]], save.tables.locally = save.tables.locally)
 
       if (do.checkSpeeds) {
         temp.valid.movements <- simplifyMovements(movements = output, tag = tag, bio = bio, discard.first = discard.first,
                                                   speed.method = speed.method, dist.mat = dist.mat)
-        output <- checkSpeeds(movements = output, tag = tag, detections = detections.list[[tag]], 
+        output <- checkSpeeds(movements = output, tag = tag, detections = detections.list[[tag]], n = counter, 
                               valid.movements = temp.valid.movements, speed.warning = speed.warning, 
                               speed.error = speed.error, GUI = GUI, save.tables.locally = save.tables.locally)
         rm(temp.valid.movements)
       }
 
       if (do.checkInactiveness) {
-        output <- checkInactiveness(movements = output, tag = tag, detections = detections.list[[tag]],
+        output <- checkInactiveness(movements = output, tag = tag, detections = detections.list[[tag]], n = counter,
                                     inactive.warning = inactive.warning, inactive.error = inactive.error,
                                     dist.mat = dist.mat, GUI = GUI, save.tables.locally = save.tables.locally)
       }  
     } else { # nocov start
       output <- overrideValidityChecks(moves = movements[[tag]], tag = tag, detections = detections.list[[tag]], 
-                                       GUI = GUI, save.tables.locally = save.tables.locally)
+                                       GUI = GUI, save.tables.locally = save.tables.locally, n = counter)
     } # nocov end
     return(output)
   })
@@ -463,7 +471,7 @@ explore <- function(
                                          valid.movements = valid.movements,
                                          spatial = spatial,
                                          rsp.info = rsp.info,
-                                         type = plot.detections.by)
+                                         y.axis = detections.y.axis)
 
     circular.plots <- printCircular(times = timesToCircular(times), 
                                     bio = bio)
@@ -472,7 +480,7 @@ explore <- function(
       sensor.plots <- printSensorData(detections = valid.detections, 
                                       spatial = spatial,
                                       rsp.info = rsp.info, 
-                                      type = plot.detections.by)
+                                      colour.by = detections.y.axis)
     } else {
       sensor.plots <- NULL
     }
@@ -494,7 +502,9 @@ explore <- function(
 # ------------------
 
 # print html report
+  trigger.report.error.message <- TRUE
   if (report) {
+    on.exit({if (trigger.report.error.message) message("M: Producing the report failed. If you have saved a copy of the results, you can reload them using dataToList().")}, add = TRUE)
     if (file.exists(reportname <- "actel_explore_report.html")) {
       continue <- TRUE
       index <- 1
@@ -521,7 +531,7 @@ explore <- function(
                     deployments = deployments,
                     detections = detections,
                     valid.detections = valid.detections,
-                    plot.detections.by = plot.detections.by)
+                    detections.y.axis = detections.y.axis)
 
     appendTo("debug", "debug: Converting report to html")
     rmarkdown::render(input = paste0(tempdir(), "/actel_report_auxiliary_files/actel_explore_report.Rmd"),
@@ -534,6 +544,7 @@ explore <- function(
       browseURL(reportname)
     } # nocov end
   }
+  trigger.report.error.message <- FALSE
 # ------------------
 
   jobname <- paste0(gsub(" |:", ".", as.character(Sys.time())), ".actel.log.txt")
@@ -589,7 +600,7 @@ explore <- function(
 #' @keywords internal
 #'
 printExploreRmd <- function(override.fragment, biometric.fragment, individual.plots,
-  circular.plots, sensor.plots, spatial, deployments, detections, valid.detections, plot.detections.by){
+  circular.plots, sensor.plots, spatial, deployments, detections, valid.detections, detections.y.axis){
 
   work.path <- paste0(tempdir(), "/actel_report_auxiliary_files/")
 
@@ -602,7 +613,7 @@ printExploreRmd <- function(override.fragment, biometric.fragment, individual.pl
     sensor.fragment <- paste0("### Sensor plots
 
 Note:
-  : The colouring in these plots will follow that of the individual detection plots, which can be modified using `plot.detections.by`.
+  : The colouring in these plots will follow that of the individual detection plots, which can be modified using `detections.y.axis`.
   : The data used for these graphics is stored in the `valid.detections` object.
   : You can replicate these graphics and edit them as needed using the `plotSensors()` function.
 
@@ -644,9 +655,9 @@ output:
 
 ### Summary
 
-Target folder: ', stringr::str_extract(pattern = '(?<=Target folder: )[^\r]*', string = report), '
+Target folder: ', stringr::str_extract(pattern = '(?<=Target folder: )[^\r|^\n]*', string = report), '
 
-Timestamp: **', stringr::str_extract(pattern = '(?<=Timestamp: )[^\r]*', string = report), '**
+Timestamp: **', stringr::str_extract(pattern = '(?<=Timestamp: )[^\r|^\n]*', string = report), '**
 
 Number of target tags: **`r I(nrow(bio))`**
 
@@ -656,7 +667,7 @@ Number of listed receivers: **', stringr::str_extract(pattern = '(?<=Number of A
 
 ', unknown.fragment,'
 
-Data time range: ', stringr::str_extract(pattern = '(?<=Data time range: )[^\r]*', string = report), '
+Data time range: ', stringr::str_extract(pattern = '(?<=Data time range: )[^\r|^\n]*', string = report), '
 
 Percentage of post-release valid detections: ', round(sum(unlist(lapply(valid.detections, nrow))) / sum(unlist(lapply(detections, nrow))) * 100, 2), '%
 
@@ -719,11 +730,11 @@ Note:
 ### Individual detection plots
 
 Note:
-  : You can choose to plot detections by station or by array using the `plot.detections.by` argument.
-  : The detections are coloured by ', ifelse(plot.detections.by == "stations", 'array', 'section'), '. The vertical black dashed line shows the release time. The full dark-grey line shows the movement events considered valid, while the dashed dark-grey line shows the movement events considered invalid.
-', ifelse(plot.detections.by == "stations", '  : The movement event lines move straight between the first and last station of each event (i.e. in-between detections will not be individually linked by the line).\n', ''),
+  : You can choose to plot detections by station or by array using the `detections.y.axis` argument.
+  : The detections are coloured by ', ifelse(detections.y.axis == "stations", 'array', 'section'), '. The vertical black dashed line shows the release time. The full dark-grey line shows the movement events considered valid, while the dashed dark-grey line shows the movement events considered invalid.
+', ifelse(detections.y.axis == "stations", '  : The movement event lines move straight between the first and last station of each event (i.e. in-between detections will not be individually linked by the line).\n', ''),
 '  : Manually **edited** tags are highlighted with **yellow** graphic borders.
-  : The ', ifelse(plot.detections.by == "stations", 'stations', 'arrays'), ' have been aligned by ', ifelse(plot.detections.by == "stations", 'array', 'section'), ', following the order provided ', ifelse(plot.detections.by == "stations", '', 'either '), 'in the spatial input', ifelse(plot.detections.by == "stations", '.', ' or the `section.order` argument.'), '
+  : The ', ifelse(detections.y.axis == "stations", 'stations', 'arrays'), ' have been aligned by ', ifelse(detections.y.axis == "stations", 'array', 'section'), ', following the order provided ', ifelse(detections.y.axis == "stations", '', 'either '), 'in the spatial input', ifelse(detections.y.axis == "stations", '.', ' or the `section.order` argument.'), '
   : You can replicate these graphics and edit them as needed using the `plotDetections()` function.
   : You can also see the movement events of multiple tags simultaneously using the `plotMoves()` function.
   : The data used in these graphics is stored in the `detections` and `movements` objects (and respective valid counterparts).
