@@ -33,8 +33,8 @@ test_that("checkMinimumN reacts as expected", {
 	xmoves <- moves
 	xmoves[[1]] <- xmoves[[1]][1, ]
 	xmoves[[1]]$Detections <- 1
-  expect_warning(output <- checkMinimumN(movements = xmoves[[1]], tag = "test", minimum.detections = 2),
-  	"Tag test only has one movement event (A1) with 1 detections. Considered invalid.", fixed = TRUE)
+  expect_warning(output <- checkMinimumN(movements = xmoves[[1]], tag = "test", minimum.detections = 2, n = "(1/1)"),
+  	"Tag test (1/1) only has one movement event (A1) with 1 detections. Considered invalid.", fixed = TRUE)
   expect_false(output$Valid)
   output <- checkMinimumN(movements = xmoves[[2]], tag = "test", minimum.detections = 2)
   expect_true(all(output$Valid))
@@ -48,8 +48,8 @@ if (interactive()) {
    	xdotmat["A7", "A8"] <- NA
       expect_error(
       	expect_warning(output <- checkImpassables(movements = moves[[1]], tag = "R64K-4451", bio = bio, 
-          spatial = spatial, dotmat = xdotmat, GUI = "never"),
-      		"Tag R64K-4451 made an impassable jump: It is not possible to go from array A1 to A2.", fixed = TRUE), 	
+          spatial = spatial, dotmat = xdotmat, GUI = "never", n = "(1/1)"),
+      		"Tag R64K-4451 (1/1) made an impassable jump: It is not possible to go from array A1 to A2.", fixed = TRUE), 	
     		"Preventing analysis from entering interactive mode in a non-interactive session.", fixed = TRUE)
   })
   # 17
@@ -61,47 +61,47 @@ test_that("checkJumpDistance reacts as expected", {
 	# jump from release to first event
 	xmoves <- moves[[1]]
 	xmoves$Array[1] <- "A3"
-	expect_warning(checkJumpDistance(movements = xmoves, bio = bio, tag = "R64K-4451", dotmat = dotmat, paths = paths,
+	expect_warning(checkJumpDistance(movements = xmoves, bio = bio, tag = "R64K-4451", dotmat = dotmat, paths = paths, n = "(1/1)",
                                    arrays = arrays, spatial = spatial, jump.warning = 1, jump.error = Inf, GUI = "never",
                                    detections = detections.list[["R64K-4451"]], save.tables.locally = FALSE),
-	"Tag R64K-4451 jumped through 2 arrays from release to first valid event (Release -> A3).", fixed = TRUE)
+	"Tag R64K-4451 (1/1) jumped through 2 arrays from release to first valid event (Release -> A3).", fixed = TRUE)
 
 	# jump from release because first event is invalid
 	xmoves <- moves[[1]]
 	xmoves$Valid[1] <- FALSE
-	expect_warning(checkJumpDistance(movements = xmoves, bio = bio, tag = "R64K-4451", dotmat = dotmat, paths = paths, 
+	expect_warning(checkJumpDistance(movements = xmoves, bio = bio, tag = "R64K-4451", dotmat = dotmat, paths = paths, n = "(1/1)",
                                    arrays = arrays, spatial = spatial, jump.warning = 1, jump.error = Inf, GUI = "never",
                                    detections = detections.list[["R64K-4451"]], save.tables.locally = FALSE),
-	"Tag R64K-4451 jumped through 1 array from release to first valid event (Release -> A2).", fixed = TRUE)
+	"Tag R64K-4451 (1/1) jumped through 1 array from release to first valid event (Release -> A2).", fixed = TRUE)
 
 	# jump from first to second event
 	xmoves <- moves[[1]]
 	xmoves$Array[2] <- "A3"
-	expect_warning(checkJumpDistance(movements = xmoves, bio = bio, tag = "R64K-4451", dotmat = dotmat, paths = paths, 
+	expect_warning(checkJumpDistance(movements = xmoves, bio = bio, tag = "R64K-4451", dotmat = dotmat, paths = paths, n = "(1/1)", 
                                    arrays = arrays, spatial = spatial, jump.warning = 1, jump.error = Inf, GUI = "never",
                                    detections = detections.list[["R64K-4451"]], save.tables.locally = FALSE),
-	"Tag R64K-4451 jumped through 1 array in valid events 1 -> 2 (A1 -> A3)", fixed = TRUE)
+	"Tag R64K-4451 (1/1) jumped through 1 array in valid events 1 -> 2 (A1 -> A3)", fixed = TRUE)
 	
 	# jump from first to third because second is invalid
 	xmoves <- moves[[1]]
 	xmoves$Array[2] <- "Unknown"
 	xmoves$Valid[2] <- FALSE
-	expect_warning(checkJumpDistance(movements = xmoves, bio = bio, tag = "R64K-4451", dotmat = dotmat, paths = paths, 
+	expect_warning(checkJumpDistance(movements = xmoves, bio = bio, tag = "R64K-4451", dotmat = dotmat, paths = paths, n = "(1/1)", 
                                    arrays = arrays, spatial = spatial, jump.warning = 1, jump.error = Inf, GUI = "never",
                                    detections = detections.list[["R64K-4451"]], save.tables.locally = FALSE),
-	"Tag R64K-4451 jumped through 1 array in valid events 1 -> 2 (A1 -> A3)", fixed = TRUE)
+	"Tag R64K-4451 (1/1) jumped through 1 array in valid events 1 -> 2 (A1 -> A3)", fixed = TRUE)
 
 	# Impassable jump exception at release
 	xdotmat <- dotmat
  	xdotmat["A1", "A2"] <- NA
   xmoves <- moves[[1]][-1, ]
-	expect_error(checkJumpDistance(movements = xmoves, bio = bio, tag = "R64K-4451", dotmat = xdotmat, paths = paths, 
+	expect_error(checkJumpDistance(movements = xmoves, bio = bio, tag = "R64K-4451", dotmat = xdotmat, paths = paths, n = "(1/1)", 
                                    arrays = arrays, spatial = spatial, jump.warning = 1, jump.error = Inf, GUI = "never",
                                    detections = detections.list[["R64K-4451"]], save.tables.locally = FALSE),
 	"There are unresolved impassable jumps in the movements (Found at release).", fixed = TRUE)
 
   # Impassable jump exception elsewhere
-  expect_error(checkJumpDistance(movements = moves[[1]], bio = bio, tag = "R64K-4451", dotmat = xdotmat, paths = paths, 
+  expect_error(checkJumpDistance(movements = moves[[1]], bio = bio, tag = "R64K-4451", dotmat = xdotmat, paths = paths, n = "(1/1)", 
                                    arrays = arrays, spatial = spatial, jump.warning = 1, jump.error = Inf, GUI = "never",
                                    detections = detections.list[["R64K-4451"]], save.tables.locally = FALSE),
   "There are unresolved impassable jumps in the movements (Found during moves).", fixed = TRUE)
@@ -114,19 +114,19 @@ test_that("checkSpeeds reacts as expected.", {
 	xmoves <- moves[[1]]
 	xmoves$Average.speed.m.s[1] <- 3
 	expect_warning(output <- checkSpeeds(movements = xmoves, tag = "R64K-4451", valid.movements = xmoves,
-    speed.warning = 3, speed.error = Inf, GUI = "never"),
-	"Tag R64K-4451 had an average speed of 3 m/s from release to first valid event (Release -> A1)", fixed = TRUE)
+    speed.warning = 3, speed.error = Inf, GUI = "never", n = "(1/1)"),
+	"Tag R64K-4451 (1/1) had an average speed of 3 m/s from release to first valid event (Release -> A1)", fixed = TRUE)
 	expect_equal(output, xmoves)
 
 	# speed warning between movements
 	expect_warning(output <- checkSpeeds(movements = moves[[1]], tag = "R64K-4451", valid.movements = moves[[1]],
-    speed.warning = 2, speed.error = Inf, GUI = "never"),
-	"Tag R64K-4451 had an average speed of 2.12 m/s from valid event 4 to 5 (A4 -> A5)", fixed = TRUE)
+    speed.warning = 2, speed.error = Inf, GUI = "never", n = "(1/1)"),
+	"Tag R64K-4451 (1/1) had an average speed of 2.12 m/s from valid event 4 to 5 (A4 -> A5)", fixed = TRUE)
 	expect_equal(output, moves[[1]])
 
 	# no warnings, runs smoothly
 	output <- checkSpeeds(movements = moves[[1]], tag = "test", valid.movements = moves[[1]],
-    speed.warning = Inf, speed.error = Inf, GUI = "never")
+    speed.warning = Inf, speed.error = Inf, GUI = "never", n = "(1/1)")
 	expect_equal(output, moves[[1]])
 })
 
@@ -134,42 +134,42 @@ test_that("checkInactiveness reacts as expected.", {
   xmoves <- moves[[1]][-c(17, 18), ]
   # With distances
   expect_warning(output <- checkInactiveness(movements = xmoves, tag = "R64K-4451", detections = detections.list[[1]],
-    inactive.warning = 1, inactive.error = Inf, dist.mat = dist.mat, GUI = "never"),
-  "Tag R64K-4451 was detected 292 times at stations less than 1.5 km apart in array 'A7' (St.9, St.10, St.11), over 2.57 days and then disappeared. Could it be inactive?", fixed = TRUE)
+    inactive.warning = 1, inactive.error = Inf, dist.mat = dist.mat, GUI = "never", n = "(1/1)"),
+  "Tag R64K-4451 (1/1) was detected 292 times at stations less than 1.5 km apart in array 'A7' (St.9, St.10, St.11), over 2.57 days and then disappeared. Could it be inactive?", fixed = TRUE)
   expect_equal(output, xmoves)
 
   # Without distances
   xdist <- dist.mat
   attributes(xdist)$valid <- FALSE
   expect_warning(output <- checkInactiveness(movements = xmoves, tag = "R64K-4451", detections = detections.list[[1]],
-    inactive.warning = 1, inactive.error = Inf, dist.mat = xdist, GUI = "never"),
-  "Tag R64K-4451 was detected 292 times at three or less stations of array 'A7' (St.9, St.10, St.11) over 2.57 days and then disappeared. Could it be inactive?", fixed = TRUE)
+    inactive.warning = 1, inactive.error = Inf, dist.mat = xdist, GUI = "never", n = "(1/1)"),
+  "Tag R64K-4451 (1/1) was detected 292 times at three or less stations of array 'A7' (St.9, St.10, St.11) over 2.57 days and then disappeared. Could it be inactive?", fixed = TRUE)
   expect_equal(output, xmoves)
 
   # no warnings
   output <- checkInactiveness(movements = xmoves, tag = "R64K-4451", detections = detections.list[[1]],
-    inactive.warning = Inf, inactive.error = Inf, dist.mat = xdist, GUI = "never")
+    inactive.warning = Inf, inactive.error = Inf, dist.mat = xdist, GUI = "never", n = "(1/1)")
   expect_equal(output, xmoves)
 
   # internal code option for no shifts
   xmoves <- moves[[1]][-c(1:6, 17, 18), ]
   output <- checkInactiveness(movements = xmoves, tag = "R64K-4451", detections = detections.list[[1]],
-    inactive.warning = Inf, inactive.error = Inf, dist.mat = xdist, GUI = "never")
+    inactive.warning = Inf, inactive.error = Inf, dist.mat = xdist, GUI = "never", n = "(1/1)")
   expect_equal(output, xmoves)
 })
 
 test_that("checkUpstream reacts as expected.", {
-  tryCatch(x <- checkUpstream(movements = moves[[1]], tag = "R64K-4451", bio = bio, spatial = spatial, arrays = arrays, GUI = "never"),
+  tryCatch(x <- checkUpstream(movements = moves[[1]], tag = "R64K-4451", bio = bio, spatial = spatial, arrays = arrays, GUI = "never", n = "(1/1)"),
     warning = function(w) stop("A warning was issued where it should not have been."))
 
   xspatial <- spatial
   xspatial$release.sites$Array <- "A2"
-  expect_warning(checkUpstream(movements = moves[[1]], tag = "R64K-4451", bio = bio, spatial = xspatial, arrays = arrays, GUI = "never"),
-    "Tag R64K-4451 was detected in an array that is not after its release site! Opening relevant data for inspection.\nExpected first array: A2", fixed = TRUE)
+  expect_warning(checkUpstream(movements = moves[[1]], tag = "R64K-4451", bio = bio, spatial = xspatial, arrays = arrays, GUI = "never", n = "(1/1)"),
+    "Tag R64K-4451 (1/1) was detected in an array that is not after its release site! Opening relevant data for inspection.\nExpected first array: A2", fixed = TRUE)
   
   xmoves <- moves[[1]]
   xmoves$Valid <- FALSE
-  tryCatch(output <- checkUpstream(movements = xmoves, tag = "R64K-4451", bio = bio, spatial = xspatial, arrays = arrays, GUI = "never"),
+  tryCatch(output <- checkUpstream(movements = xmoves, tag = "R64K-4451", bio = bio, spatial = xspatial, arrays = arrays, GUI = "never", n = "(1/1)"),
     warning = function(w) stop("A warning was issued where it should not have been."))
   expect_equal(output, xmoves)
 })
